@@ -5,10 +5,8 @@ pub const TEST_DIRECTORY: &str = "tests";
 pub const SWAY_EXTENSION: &str = "sw";
 pub const USER_FORC_DIRECTORY: &str = ".forc";
 pub const SRC_DIR: &str = "src";
-pub const SWAY_PREDICATE: &str = "predicate";
-pub const SWAY_LIBRARY: &str = "library";
-pub const SWAY_SCRIPT: &str = "script";
-pub const SWAY_CONTRACT: &str = "contract";
-pub const DEFAULT_NODE_URL: &str = "127.0.0.1:4000";
+pub const DEFAULT_NODE_URL: &str = "http://127.0.0.1:4000";
 pub const LANGUAGE_NAME: &str = "Sway";
 pub const STORAGE_DOMAIN_SEPARATOR: &str = "storage_";
+pub const LIB_ENTRY: &str = "lib.sw";
+pub const MAIN_ENTRY: &str = "main.sw";
